@@ -55,7 +55,8 @@ class SweepProvider():
 
 class DataProvider():
     """
-    Fetches data from DataStorage for a specific readable parameter
+    Fetches data from DataStorage for a specific measured parameter
+    with additional capability of sweep filtering.
     """
 
     def __init__(self, data_storage, measurable_ind):
@@ -116,7 +117,7 @@ class DataProvider():
             data = data[self.filter_x::2]
         return len(data)
 
-    def get_sweep(self, sweep_id):
+    def get_curve(self, sweep_id):
         """
         Return the dataset for a specified sweep
 
@@ -136,7 +137,7 @@ class DataProvider():
         return SweepProvider(data[sweep_id], self.measurable_ind)
 
     def get_sweepables(self):
-        return self.data_storage.writables
+        return self.data_storage.get_sweepables()
 
     def get_measurables(self):
-        return [self.data_storage.readables[self.measurable_ind]]
+        return [self.data_storage.get_measurables()[self.measurable_ind]]
