@@ -32,9 +32,7 @@ class SweepStorage():
     def __init__(self, time, writable, readables):
         self._time = time
         self._wrdata = writable.values
-        #self._writable = writable
         self._rddata = [rdev._values for rdev in readables]
-        #self._readables = readables
 
     def read_data(self):
         """
@@ -59,14 +57,11 @@ class DataStorage():
     Stores the measured data for the entire experiment
     """
 
-    def __init__(self):
-        self._curves = []
-
-    def reset(self):
-        """
-        Empty the data storage
-        """
+    def __init__(self, sweepables, measurables, repeat_num):
         self._curves = []
+        self._sweepables = sweepables
+        self._measurables = measurables
+        self._repeat_num = repeat_num
 
     def add_curve(self, time, writable, readables):
         """
@@ -75,8 +70,45 @@ class DataStorage():
         """
         self._curves.append(SweepStorage(time, writable, readables))
 
+    def get_curve(self, index):
+        """
+        Return the dataset for a specified curve.
+
+        Parameters
+        ----------
+        index : int
+            The index of the sweep to fetch (-1 = the last).
+
+        Returns
+        -------
+        SweepProvider
+            The fetched sweep object
+        """
+        return self._curves[index]
+
+    def get_repeat_num(self):
+        """
+        Returns the number of times curves are measured with
+        same parameters.
+
+        Returns
+        -------
+        int
+        """
+        return self._repeat_num
+
     def get_data(self):
         """
-        Get all the stored curves
+        Get all the stored curves.
+
+        Returns
+        -------
+        list of SweepProvider
         """
         return self._curves
+
+    def get_sweepables(self):
+        return self._sweepables
+
+    def get_measurables(self):
+        return self._measurables
