@@ -51,13 +51,13 @@ class DeviceOption(metaclass=ABCMeta):
     @abstractmethod
     def get_value(self):
         """
-        Retrieve the option value
+        Retrieve the control value
         """
 
     @abstractmethod
     def set_value(self, value):
         """
-        Set the option value
+        Set the control value
         """
 
     def is_enabled(self):
@@ -110,10 +110,6 @@ class DeviceOption(metaclass=ABCMeta):
     def device_id(self):
         return self.device.device_id()
 
-    def is_sweep_based(self):
-        # TODO: remove
-        return False
-
     @property
     def location(self):
         return self.device.location
@@ -138,7 +134,9 @@ class ListControl(DeviceOption):
         self._values_list = values_list
 
     def values_list(self):
-        """return the list of the valid values"""
+        """
+        Return the list of the valid values
+        """
         return self._values_list
 
     def get_value(self):
@@ -200,19 +198,55 @@ class ValueDeviceOption(DeviceOption):
             self, name, phys_q, get_func=None, set_func=None, channels=1,
             validator=EmptyValidator, enabled=None, sweepable=True
         ):
+        """
+        Create new sweep control.
+
+        Parameters
+        ----------
+        name : str
+            The name of this control.
+
+        phys_q : callable or str
+            Physical quantity. Can be None.
+
+        get_func : callable
+            A function or lambda in the instrument class.
+            Should accept no arguments and return a value or list.
+
+        set_func : callable or None
+
+        channels : callable or int
+            The vector length for each data point.
+
+        enabled : callable or None
+            If the control is currently enabled. None means always enabled.
+        """
         super().__init__(name, get_func, set_func, enabled)
         self._phys_q = phys_q
         self._validator = validator
         self._channels = channels
         self._sweepable = sweepable
 
-    def phys_quantity(self):
+    def get_phys_q(self):
         """
-        Get physical quantity (if applicable)
+        Get the physical quantity, associated with control.
+
+        Returns
+        -------
+        phys_q : The physical quantity.
         """
+        if callable(self._phys_q):
+            return self._phys_q()
         return self._phys_q
 
     def get_value(self):
+        """
+        Measure and return the value of control.
+
+        Returns
+        -------
+        value : The measured value.
+        """
         return self._fget()
 
     def set_value(self, value):
@@ -223,6 +257,8 @@ class ValueDeviceOption(DeviceOption):
         ret = super().with_instance(device)
         if callable(self._channels):
             ret._channels = self._channels.__get__(device, device.__class__)
+        if callable(self._phys_q):
+            ret._phys_q = self._phys_q.__get__(device, device.__class__)
         return ret
 
     def is_sweepable(self):
@@ -245,35 +281,46 @@ class ValueDeviceOption(DeviceOption):
         """
         Return the length of the output data vector
         """
+        if callable(self._channels):
+            return self._channels()
         return self._channels
 
-class SweepControl(DeviceOption):
+class SweepControl(ValueDeviceOption):
     """
     Sweep control represent a capability of making sweep measurement of
-    one parameter against the other
+    one parameter versus the other. Each acquisition results in a dataset.
     """
 
-    def get_sweep_range(self):
-        """
-        This routine shall return the range of control paramter. This
-        range is to be immutable in a single experiment.
+    def __init__(self, name, axes_names, phys_q, get_func, channels=1, enabled=None):
         """
+        Create new sweep control.
 
-    def get_sweep_physq(self):
-        """
-        Return the physical quantity, associated with control parameter
-        """
+        Parameters
+        ----------
+        name : str
+            The name of this control.
 
-    def get_value(self):
-        """
-        Measure a new trace and return it
-        """
+        axes_names: Tuple (str, str)
+            Names for the parameters
 
-    def phys_quantity(self):
+        phys_q : Tuple (str, str)
+            Physical quantity (Tuple of strings for x and y). Any can be None.
+
+        get_func : callable
+            A function or lambda in the instrument class.
+            Should accept no arguments and return a list.
+
+        channels : callable or int
+            The vector length for each data point.
+
+        enabled : callable or None
+            If the control is currently enabled. None means always enabled.
         """
-        Get physical quantity (if applicable)
-        """
-        return self._phys_q
+        super().__init__(name, phys_q, get_func, None, channels, enabled)
+        self._axes_names = axes_names
+
+    def get_axes_names(self):
+        return self._axes_names
 
 class StateControl(DeviceOption):
     """
