@@ -26,6 +26,7 @@
 """
 
 import logging
+from pyxperiment.frames.device_config import DeviceConfig
 import sys
 import wx
 import matplotlib
@@ -38,6 +39,7 @@ class PyXperimentApp():
     _settings = None
     _resource_manager = None
     _wx_app = None
+    _instr_conf_dict = dict()
 
     def __init__(self):
         if PyXperimentApp._wx_app is None:
@@ -60,23 +62,31 @@ class PyXperimentApp():
 
     @staticmethod
     def log_excepthook(exc_type, exc_value, exc_traceback):
-        """Logs the unhandled exception to log file"""
+        """
+        Logs the unhandled exception to log file
+        """
         if not issubclass(exc_type, KeyboardInterrupt):
             logging.error("Uncaught exception", exc_info=(exc_type, exc_value, exc_traceback))
         sys.__excepthook__(exc_type, exc_value, exc_traceback)
 
     @property
     def frame(self):
-        """Get the application main frame"""
+        """
+        Get the application main frame
+        """
         return PyXperimentApp._wx_app.frame
 
     @frame.setter
     def frame(self, value):
-        """Set the application main frame"""
+        """
+        Set the application main frame
+        """
         PyXperimentApp._wx_app.frame = value
 
     def start(self):
-        """Start the application main loop"""
+        """
+        Start the application main loop
+        """
         if not PyXperimentApp._is_running:
             if self.frame:
                 self.frame.Show()
@@ -87,10 +97,34 @@ class PyXperimentApp():
 
     @property
     def resource_manager(self):
-        """Get the global resource manager"""
+        """
+        Get the global resource manager
+        """
         return PyXperimentApp._resource_manager
 
     @property
     def settings(self):
-        """Get the global application settings"""
+        """
+        Get the global application settings
+        """
         return PyXperimentApp._settings
+
+    def show_conf_wnd(self, instr):
+        """
+        Show the configuration dialog for a specified instrument.
+        PyXperiment ensures, that only one such dialog is open
+        for a specified device.
+        """
+        # check if a window is already open
+        if instr in PyXperimentApp._instr_conf_dict:
+            wnd = PyXperimentApp._instr_conf_dict[instr]
+            if wnd:
+                return
+        # no active window, need to open
+        if hasattr(instr, 'get_config_class') and callable(instr.get_config_class):
+            config = instr.get_config_class()
+            conf_wnd = config(self.frame, instr)
+        else:
+            conf_wnd = DeviceConfig(self.frame, instr)
+        conf_wnd.Show()
+        PyXperimentApp._instr_conf_dict[instr] = conf_wnd
