@@ -195,11 +195,11 @@ class Experiment():
         """
 
         # Actualize the file number
-        self.data_writer.start_new_file()
+        self.data_writer.update_filename()
         # Save experiment information
         self.data_writer.save_info_file(
-            [dev.description() for dev in self.data_context.readables],
-            [dev.description() for dev in self.data_context.writables],
+            [dev.description() for dev in self.data_context.get_measurables()],
+            [dev.description() for dev in self.data_context.get_sweepables()],
             [
                 ('Repeat each curve', str(self.data_context.curves_num)),
                 ('Delay between curves', str(self.data_context.curves_delay)),
