@@ -25,6 +25,8 @@
     THE SOFTWARE.
 """
 
+import datetime
+import itertools
 from .text_data_format import TextDataWriter
 
 class ColumnedDataWriter(TextDataWriter):
@@ -32,26 +34,43 @@ class ColumnedDataWriter(TextDataWriter):
     Implements the data storaging for columned scans
     """
 
-    def after_sweep(self, num, data_context):
+    def after_sweep(self, num, data_storage):
         if num == 1:
-            self.save_internal(data_context)
-            self.start_new_file()
+            self.save_internal(data_storage)
+            self.update_filename()
 
-    def save_internal(self, data_context):
-        """Сохранение данных в файл"""
-        wr_data = []
-        for wr_w in data_context.writables[1].values:
-            for i in range(data_context.curves_num):
-                wr_data.append(wr_w)
-
-        index = data_context.writables[1].index * data_context.curves_num + (data_context._curve - 1)
+    def save_file(self, timecol, xcol, data):
+        file_name = self.get_filename()
+        with open(file_name, "w") as text_file:
+            for i in range(len(xcol)):
+                if i >= len(timecol):
+                    print('NaN', end=' ', file=text_file)
+                elif isinstance(timecol[i], datetime.datetime):
+                    print(datetime.datetime.isoformat(timecol[i]), end=' ', file=text_file)
+                else:
+                    print(str(int(timecol[i]*1000)), end=' ', file=text_file)
+                print(str(xcol[i]), end=' ', file=text_file)
+                if i < len(timecol):
+                    print(*[str(data_line[i]) for data_line in data], file=text_file)
+                else:
+                    print(*['NaN' for data_line in data], file=text_file)
 
+    def save_internal(self, data_storage):
+        """
+        Save the measured data to file
+        """
+        wr_data = list(
+            itertools.chain.from_iterable(
+                itertools.repeat(x, data_storage.get_repeat_num())
+                for x in data_storage.get_sweepables()[1].values
+                ))
+        curves = data_storage.get_data()
         rd_data = []
-        curves = data_context.all_data.get_data()
         for i in range(len(curves[0].read_data()[0])):
             rd_data.append(list((curve.read_data()[0][i] if i < len(curve.read_data()[0]) else 'NaN') for curve in curves))
         time_data = [curve.time_markers()[0] for curve in curves]
         self.save_file(time_data, wr_data, rd_data)
 
     def get_format_name(self):
+        """Get the human readable format name"""
         return 'Text file with curves as rows'
