@@ -138,8 +138,8 @@ class SRSDC205Source(VisaInstrument):
     def set_range(self, value):
         try:
             volt_range = self.volt_range_values[value]
-        except KeyError:
-            raise ValueError('Invalid range: ' + value)
+        except KeyError as exc:
+            raise ValueError('Invalid range: ' + value, exc) from exc
         self.write('RNGE ' + volt_range[0])
 
     volt_range = ListControl(
