@@ -26,9 +26,13 @@
 
 import random
 import time
+from decimal import Decimal
 
-from pyxperiment.controller.device_options import ActionControl, ValueDeviceOption
+from pyxperiment.core.utils import str_to_range
 from pyxperiment.controller.instrument import Instrument
+from pyxperiment.controller.device_options import (
+    ActionControl, SweepControl, ValueDeviceOption as ValueControl
+)
 from pyxperiment.controller.validation import StaticRangeValidator
 
 class TestDevice(Instrument):
@@ -37,7 +41,7 @@ class TestDevice(Instrument):
         super().__init__('')
         del rm
         self.last_value = 0
-        self.last_value2 = 0
+        self.up_value = Decimal('0')
         self._rand_channels = 1
         self.options = [
             self.channels, self.reset
@@ -46,7 +50,7 @@ class TestDevice(Instrument):
 
     def _reset(self):
         self.last_value = 0
-        self.last_value2 = 0
+        self.up_value = Decimal('0')
 
     def get_channels_num(self):
         return str(self._rand_channels)
@@ -69,9 +73,10 @@ class TestDevice(Instrument):
         return str(self.last_value)
 
     def get_value2(self):
-        self.last_value2 += 0.1
+        value = str(self.up_value)
+        self.up_value += Decimal('0.1')
         #time.sleep(0.01)
-        return str(self.last_value2)
+        return str(value)
 
     def set_value(self, value):
         self.last_value = value
@@ -79,10 +84,10 @@ class TestDevice(Instrument):
     def get_random(self):
         #time.sleep(0.1)
         if self._rand_channels == 1:
-            return str(random.triangular(-10, 10))
-        return [str(random.triangular(-10, 10)) for i in range(self._rand_channels)]
+            return f"{(random.triangular(-10, 10)):.3f}"
+        return [f"{(random.triangular(-10, 10)):.3f}" for i in range(self._rand_channels)]
 
-    channels = ValueDeviceOption(
+    channels = ValueControl(
         'Random channels', None,
         get_func=get_channels_num,
         set_func=set_channels_num,
@@ -90,17 +95,26 @@ class TestDevice(Instrument):
         sweepable=False
         )
 
-    value = ValueDeviceOption(
+    value = ValueControl(
         'Sweepable', 'V', get_value, set_value,
         validator=StaticRangeValidator('-10', '10', '0.01')
         )
-    value2 = ValueDeviceOption(
+    value2 = ValueControl(
         'Measurable Up', 'V', get_value2
         )
-    rand = ValueDeviceOption(
+    rand = ValueControl(
         'Measurable Random', 'V', get_random, None, lambda self: int(self.get_channels_num())
         )
 
+    sweep = SweepControl(
+        'Test sweep', ('Frequency', 'Power'), ('Hz','dB'),
+        get_func=lambda instr:
+            (
+                list(map(str, str_to_range('1000:2:2000'))),
+                [f"{(random.triangular(-10, 10)):.3f}" for i in range(501)]
+                )
+    )
+
     reset = ActionControl(
         'Reset', _reset
     )
