@@ -50,7 +50,7 @@ class Yokogawa7651(VisaInstrument):
         self.inst.write('H1', '\n')
         self.set_options([
             ListControl(
-                'Function', self.function_values, self.get_function, self.set_function),
+                'Function', self.function_values.keys(), self.get_function, self.set_function),
             ListControl(
                 'Range', [], self.get_range, self.set_range),
             ValueDeviceOption(
@@ -98,7 +98,7 @@ class Yokogawa7651(VisaInstrument):
 
     output = BooleanControl(
         'Output on',
-        get_func=lambda instr: int(instr.query('OC')[5:]) & 1 << 4,
+        get_func=lambda instr: (int(instr.query('OC')[5:]) & 1 << 4) >> 4,
         set_func=lambda instr, val: instr.write('O' + val)
         )
 
@@ -120,8 +120,8 @@ class Yokogawa7651(VisaInstrument):
     def set_function(self, value):
         try:
             cmd = self.function_values[value]
-        except KeyError:
-            raise ValueError('Invalid function: ' + value)
+        except KeyError as exc:
+            raise ValueError('Invalid function: ' + value, exc) from exc
         self.write(cmd)
 
     volt_range_values = {
@@ -156,8 +156,8 @@ class Yokogawa7651(VisaInstrument):
     def set_range(self, value):
         try:
             cmd = self.volt_range_values[value]
-        except KeyError:
-            raise ValueError('Invalid range: ' + value)
+        except KeyError as exc:
+            raise ValueError('Invalid range: ' + value, exc) from exc
         self.write(cmd[0])
 
     def get_volt_limit(self):
@@ -197,7 +197,7 @@ class Yokogawa7651Config(DeviceConfig):
 
     def _create_controls(self):
         self.controls = []
-        self.function = CaptionDropBox(self.panel, 'Function', Yokogawa7651.function_values)
+        self.function = CaptionDropBox(self.panel, 'Function', Yokogawa7651.function_values.keys())
         self.controls.append(self.function)
         self.range = CaptionDropBox(self.panel, 'Range', [])
         self.controls.append(self.range)
@@ -227,10 +227,10 @@ class Yokogawa7651Config(DeviceConfig):
         self.voltage_limit.SetValue(self.device.get_volt_limit())
         self.current_limit.SetValue(self.device.get_curr_limit())
         self.value.SetValue(str(Decimal(self.device.get_value())))
-        self.output.SetValue(self.device.get_output())
+        self.output.SetValue(self.device.output.get_value())
 
     def write_control(self):
-        if self.output.IsModified() and self.output.GetValue() != self.device.get_output():
+        if self.output.IsModified() and self.output.GetValue() != self.device.output.get_value():
             dlg = wx.MessageDialog(
                 self,
                 'Warning! you are trying to modify a' +
@@ -242,7 +242,7 @@ class Yokogawa7651Config(DeviceConfig):
                 )
             if dlg.ShowModal() != wx.ID_YES:
                 return
-            self.device.set_output(self.output.GetValue())
+            self.device.output.set_value(self.output.GetValue())
         if self.range.IsModified():
             self.device.set_range(self.range.GetValue())
         if self.value.IsModified():
