@@ -38,8 +38,6 @@ class ExperimentControlFrame(wx.Frame):
     The frame provides graphics for experiment control
     """
 
-    title = 'Experiment control'
-
     class XShowPanel(wx.Panel):
         def __init__(self, parent, writable):
             super().__init__(parent, wx.ID_ANY)
@@ -71,7 +69,7 @@ class ExperimentControlFrame(wx.Frame):
             self.edit_value.edit.Value = str(Decimal(self.writable.value))
 
     def __init__(self, parent, dataContext, cumulative, auto_close=False):
-        super().__init__(parent, wx.ID_ANY, self.title)
+        super().__init__(parent, wx.ID_ANY, 'Experiment control')
         self.Bind(wx.EVT_CLOSE, self.on_close)
 
         self.parent = parent
@@ -98,12 +96,12 @@ class ExperimentControlFrame(wx.Frame):
                 self.panel, DataProvider(self.dataContext, i),
                 DataViewMode.CUMULATIVE if cumulative else DataViewMode.SIMPLE
                 )
-            for i in range(len(self.dataContext.readables))
+            for i in range(len(self.dataContext.get_measurables()))
             ]
 
         self.panels_calibrators = [
             ExperimentControlFrame.XShowPanel(self.panel, writable)
-            for writable in self.dataContext.writables
+            for writable in self.dataContext.get_sweepables()
             ]
 
         self.save_button = wx.Button(self.panel, wx.ID_ANY, "Save", size=(100, 35))
@@ -182,8 +180,8 @@ class ExperimentControlFrame(wx.Frame):
 
     def on_pause_button(self, event):
         del event
-        self.dataContext.pause(not self.dataContext.isPaused)
-        self.pause_button.SetLabel("Resume" if self.dataContext.isPaused else "Pause")
+        self.dataContext.pause(not self.dataContext.is_paused)
+        self.pause_button.SetLabel("Resume" if self.dataContext.is_paused else "Pause")
 
     def on_go_to_start_button(self, event):
         del event
