@@ -36,8 +36,7 @@ from matplotlib.figure import Figure
 from matplotlib.backends.backend_wxagg import \
     FigureCanvasWxAgg as FigCanvas, \
     NavigationToolbar2WxAgg
-from pyxperiment.controller.device_control import SweepReadableControl
-from pyxperiment.controller.device_options import ValueDeviceOption
+from pyxperiment.controller.device_options import SweepControl, ValueDeviceOption
 
 class NavigationToolbar(NavigationToolbar2WxAgg):
     """
@@ -139,20 +138,8 @@ class DataViewAxis(wx.Panel):
             ' at ' + self.measurable.location,
             size=10
             )
-        if isinstance(self.measurable.device, ValueDeviceOption):
-            if self.measurable.device.phys_quantity() is not None:
-                self.axes.set_ylabel(
-                    self.measurable.device.name + ', ' + self.measurable.device.phys_quantity()
-                    )
-            else:
-                self.axes.set_ylabel(self.measurable.device.name)
-        if isinstance(self.sweepable.device, ValueDeviceOption):
-            if self.sweepable.device.phys_quantity() is not None:
-                self.axes.set_xlabel(
-                    self.sweepable.device.name + ', ' + self.sweepable.device.phys_quantity()
-                    )
-            else:
-                self.axes.set_xlabel(self.sweepable.device.name)
+
+        self._set_axes_labels()
 
         if self.measurable.num_channels() > len(self.PLOT_COLORS):
             self.PLOT_COLORS = [self.PLOT_COLORS[1]] * self.measurable.num_channels()
@@ -176,8 +163,40 @@ class DataViewAxis(wx.Panel):
             ]
         self.current_curve = 0
         self.ylimits = [None, None]
+        if isinstance(self.measurable.device, SweepControl):
+            self.cb_autox.Value = True
+            self.cb_autox.Disable()
         self._set_xscale()
 
+    def _set_axes_labels(self):
+        # TODO: Remove this decisions
+        if isinstance(self.measurable.device, SweepControl):
+            self.axes.set_xlabel(
+                self.measurable.device.get_axes_names()[0] +
+                (', ' + self.measurable.device.get_phys_q()[0]) if
+                self.measurable.device.get_phys_q()[0] is not None else ''
+                )
+            self.axes.set_ylabel(
+                self.measurable.device.get_axes_names()[1] +
+                (', ' + self.measurable.device.get_phys_q()[1]) if
+                self.measurable.device.get_phys_q()[1] is not None else ''
+                )
+            return
+        if isinstance(self.measurable.device, ValueDeviceOption):
+            if self.measurable.device.get_phys_q() is not None:
+                self.axes.set_ylabel(
+                    self.measurable.device.name + ', ' + self.measurable.device.get_phys_q()
+                    )
+            else:
+                self.axes.set_ylabel(self.measurable.device.name)
+        if isinstance(self.sweepable.device, ValueDeviceOption):
+            if self.sweepable.device.get_phys_q() is not None:
+                self.axes.set_xlabel(
+                    self.sweepable.device.name + ', ' + self.sweepable.device.get_phys_q()
+                    )
+            else:
+                self.axes.set_xlabel(self.sweepable.device.name)
+
     def _on_resize(self, event):
         event.Skip()
         size = self.GetSize()
@@ -187,11 +206,8 @@ class DataViewAxis(wx.Panel):
                 )
 
     def _set_xscale(self):
-        if isinstance(self.measurable, SweepReadableControl):
-            xdata = list(map(float, self.measurable.get_sweep_x()))
-        else:
+        if not isinstance(self.measurable.device, SweepControl):
             xdata = self.sweepable.values
-        if xdata:
             self.axes.set_xbound(lower=min(xdata), upper=max(xdata))
 
     def _on_cb_xlab(self, event):
@@ -201,16 +217,19 @@ class DataViewAxis(wx.Panel):
         self.draw_plot()
 
     def _plot_sweep_data(self, sweep):
-        # get x axis data
-        if isinstance(self.measurable, SweepReadableControl):
-            self._set_xscale()
-            xdata = self.measurable.get_sweep_x()
+        # Get the actual data
+        if isinstance(self.measurable.device, SweepControl):
+            if not sweep.read_data():
+                return
+            data = sweep.read_data()[-1]
+            xdata = data[0]
+            ydata = data[1]
         else:
             xdata = sweep.write_data()
+            ydata = sweep.read_data()
         # if sweep is not finished yet, cut it
-        ydata = sweep.read_data()
         xdata = np.fromiter(itertools.islice(xdata, len(ydata)), float, len(ydata))
-        # Get the actual new data and convert it to floats
+        # Convert data to floats
         for i, curve in enumerate(self.plot_curves):
             if len(self.plot_curves) > 1:
                 ydata_ch = np.fromiter(
@@ -243,7 +262,7 @@ class DataViewAxis(wx.Panel):
             # If new curves appeared
             while sweeps_ready-1 > self.current_curve:
                 self._plot_sweep_data(
-                    self.data_provider.get_sweep(self.current_curve)
+                    self.data_provider.get_curve(self.current_curve)
                     )
                 for curve in self.plot_curves:
                     # Make previous curves faint
@@ -259,7 +278,7 @@ class DataViewAxis(wx.Panel):
         else:
             self.ylimits = [None, None]
 
-        sweep = self.data_provider.get_sweep(-1)
+        sweep = self.data_provider.get_curve(-1)
         # TODO: check that data actually changed
         self._plot_sweep_data(sweep)
 
